==> vue-components-1.5.13.tgz: package/lib/fileUpload/src/UploadIcon.vue.rd.js <==
import { useInjectStyle as t } from "../../shared/hooks/useInjectStyle.rd.js";
import { defineComponent as s, openBlock as n, createElementBlock as o, createElementVNode as a, normalizeClass as l } from "vue";
import { uploadIconProps as i } from "./props.rd.js";
import r from "./uploadIcon.scss.rd.js";
const c = {
  "xml:space": "preserve",
  viewBox: "0 0 100 100",
  y: "0",
  x: "0",
  xmlns: "http://www.w3.org/2000/svg",
  version: "1.1",
  style: { background: "rgb(255, 255, 255)" }
}, d = {
  class: "ldl-scale",
  style: { "transform-origin": "50% 50%", transform: "rotate(0deg) scale(0.8, 0.8)" }
}, m = { class: "ldl-ani" }, p = { class: "ldl-layer" }, f = {
  class: "ldl-ani",
  style: { transform: "scale(0.91)", "transform-origin": "50px 50px" }
}, _ = { class: "ldl-layer" }, g = {
  class: "ldl-ani",
  style: { transform: "scale(0.91)", "transform-origin": "50px 50px" }
}, k = /* @__PURE__ */ s({
  __name: "UploadIcon",
  props: i(),
  setup(u) {
    return t(r, "upload-icon"), (e, h) => (n(), o("svg", c, [
      a("g", d, [
        a("g", m, [
          a("g", p, [
            a("g", f, [
              a("path", {
                fill: "#666",
                "clip-rule": "evenodd",
                "fill-rule": "evenodd",
                d: "M95 64.076c0-6.877-4.478-12.7-10.673-14.736.215-1.436.329-2.906.329-4.402 0-16.283-13.2-29.483-29.483-29.483-13.982 0-25.683 9.737-28.712 22.798-.258-.01-.51-.039-.771-.039C14.263 38.214 5 47.477 5 58.904c0 11.427 9.263 20.69 20.69 20.69h55.862v-.154C89.141 78.426 95 71.943 95 64.076z",
                style: { "animation-iteration-count": "infinite" },
                class: l([{
                  "animate-bubble animated animate-duration-800": e.animated,
                  "!fill-slate-300 dark:!fill-slate-700": e.gray
                }, "!fill-primary-600"])
              }, null, 2)
            ])
          ]),
          a("g", _, [
            a("g", g, [
              a("path", {
                id: "XMLID_7_",
                fill: "#fff",
                d: "M69.694 64.662c.766 0 1.166-.948.649-1.537L52.224 42.532a.86.86 0 0 0-1.298 0L32.809 63.125c-.517.588-.117 1.537.649 1.537h12.598v15.889c0 .709.551 1.283 1.231 1.283h8.578c.68 0 1.231-.574 1.231-1.283V64.662h12.598z",
                style: { fill: "rgb(255, 255, 255)", "animation-iteration-count": "infinite" },
                class: l({
                  "animate-bubble animated animate-duration-800 animate-delay-400": e.animated,
                  "dark:!fill-slate-400": e.gray
                })
              }, null, 2)
            ])
          ])
        ])
      ])
    ]));
  }
});
export {
  k as default
};

==> vue-components-1.6.6.tgz: package/lib/fileUpload/src/UploadIcon.vue.rd.js <==
import { useInjectStyle as t } from "../../shared/hooks/useInjectStyle.rd.js";
import { defineComponent as s, openBlock as n, createElementBlock as i, createElementVNode as a, normalizeClass as l } from "vue";
import { uploadIconProps as o } from "./props.rd.js";
import r from "./uploadIcon.scss.rd.js";
const c = {
  "xml:space": "preserve",
  viewBox: "0 0 100 100",
  y: "0",
  x: "0",
  xmlns: "http://www.w3.org/2000/svg",
  version: "1.1",
  style: { background: "rgb(255, 255, 255)" }
}, d = {
  class: "ldl-scale",
  style: { "transform-origin": "50% 50%", transform: "rotate(0deg) scale(0.8, 0.8)" }
}, m = { class: "ldl-ani" }, p = { class: "ldl-layer" }, f = {
  class: "ldl-ani",
  style: { transform: "scale(0.91)", "transform-origin": "50px 50px" }
}, _ = { class: "ldl-layer" }, g = {
  class: "ldl-ani",
  style: { transform: "scale(0.91)", "transform-origin": "50px 50px" }
}, x = /* @__PURE__ */ s({
  __name: "UploadIcon",
  props: o(),
  setup(u) {
    return t(r, "upload-icon"), (e, h) => (n(), i("svg", c, [
      a("g", d, [
        a("g", m, [
          a("g", p, [
            a("g", f, [
              a("path", {
                fill: "#666",
                "clip-rule": "evenodd",
                "fill-rule": "evenodd",
                d: "M95 64.076c0-6.877-4.478-12.7-10.673-14.736.215-1.436.329-2.906.329-4.402 0-16.283-13.2-29.483-29.483-29.483-13.982 0-25.683 9.737-28.712 22.798-.258-.01-.51-.039-.771-.039C14.263 38.214 5 47.477 5 58.904c0 11.427 9.263 20.69 20.69 20.69h55.862v-.154C89.141 78.426 95 71.943 95 64.076z",
                style: { "animation-iteration-count": "infinite" },
                class: l([{
                  "animate-bubble animated animate-duration-800": e.animated,
                  "!fill-slate-300 dark:!fill-slate-700": e.gray
                }, "!fill-primary-400 dark:!fill-primary-700"])
              }, null, 2)
            ])
          ]),
          a("g", _, [
            a("g", g, [
              a("path", {
                id: "XMLID_7_",
                fill: "#fff",
                d: "M69.694 64.662c.766 0 1.166-.948.649-1.537L52.224 42.532a.86.86 0 0 0-1.298 0L32.809 63.125c-.517.588-.117 1.537.649 1.537h12.598v15.889c0 .709.551 1.283 1.231 1.283h8.578c.68 0 1.231-.574 1.231-1.283V64.662h12.598z",
                style: { fill: "rgb(255, 255, 255)", "animation-iteration-count": "infinite" },
                class: l({
                  "animate-bubble animated animate-duration-800 animate-delay-400": e.animated,
                  "dark:!fill-slate-400": e.gray
                })
              }, null, 2)
            ])
          ])
        ])
      ])
    ]));
  }
});
export {
  x as default
};
